var chai = require('chai');
var expect = chai.expect;

var Validator = require('./index.js');

describe('Validate', function() {

    it('No type specified', function() {
        var res = Validator({
            name: {
                defaultValue: 17
            }
        }, {
            name: 'Yuriy'
        });

        expect(res.status).to.equal('schemaError');
    });

    it('Default value without optional', function() {
        var res = Validator({
            name: {
                type: 'number',
                defaultValue: 17
            }
        }, {
            name: 'Yuriy'
        });

        expect(res.status).to.equal('schemaError');
    });

    it('Valid object', function () {
        var schema = {
            name: {
                type: 'string',
                length: {
                    min: 3,
                    max: 30
                }
            },
            age: {
                type: 'number',
                minValue: 5,
                maxValue: 150
            },
            gender: {
                type: 'string',
                optional: true,
                defaultValue: 'man'
            },
            married: {
                type: 'boolean',
                optional: true,
                defaultValue: false
            }
        };

        var res = Validator(schema, {
            name: 'Yuriy',
            age: 17,
            married: true
        });

        console.log('res', res);
        expect(res.status).to.equal('success');
        expect(res.value).to.be.a('object');
        expect(res.value.name).to.equal('Yura');
        expect(res.value.age).to.equal(17);
        expect(res.value.gender).to.equal('man');
        expect(res.value.married).to.equal(true);
    });

    it('Error in object', function () {
        var res = Validator({
            name: {
                type: 'string',
                minLength: 5,
                maxLength: 30
            }
        }, {
            name: 'Yuriy'
        });

        expect(res.status).to.equal('error');
        expect(res.errors).to.be.a('array');
        expect(res.errors[0]).to.be.a('object');
        expect(res.errors[0].key).to.equal('name');
        expect(res.errors[0].message).to.equal('string length is less than min length');
    });

    it('Valid multi types', function () {
        var res = Validator({
            name: {
                type: 'string|number',
                allowedValues: ['Yuriy']
            }
        }, {
            name: 'Yuriy'
        });

        expect(res.status).to.equal('success');
        expect(res.value).to.be.a('object');
        expect(res.value.name).to.equal('Yuriy');
    });
});

